@@ -1,8 +1,9 @@
+import codecs
 import socket
 import struct
 from collections import defaultdict, deque
-from distutils.version import LooseVersion
 from hashlib import md5
+from io import TextIOBase
 from itertools import count
 from struct import Struct
 
@@ -101,15 +102,15 @@ TERMINATE = b"X"
 CLOSE = b"C"
 
 
-def create_message(code, data=b""):
+def _create_message(code, data=b""):
     return code + i_pack(len(data) + 4) + data
 
 
-FLUSH_MSG = create_message(FLUSH)
-SYNC_MSG = create_message(SYNC)
-TERMINATE_MSG = create_message(TERMINATE)
-COPY_DONE_MSG = create_message(COPY_DONE)
-EXECUTE_MSG = create_message(EXECUTE, NULL_BYTE + i_pack(0))
+FLUSH_MSG = _create_message(FLUSH)
+SYNC_MSG = _create_message(SYNC)
+TERMINATE_MSG = _create_message(TERMINATE)
+COPY_DONE_MSG = _create_message(COPY_DONE)
+EXECUTE_MSG = _create_message(EXECUTE, NULL_BYTE + i_pack(0))
 
 # DESCRIBE constants
 STATEMENT = b"S"
@@ -342,114 +343,124 @@ class CoreConnection:
 
         self.in_transaction = False
 
-    def register_out_adapter(self, typ, oid, out_func):
-        self.py_types[typ] = (oid, out_func)
+    def register_out_adapter(self, typ, out_func):
+        self.py_types[typ] = out_func
 
     def register_in_adapter(self, oid, in_func):
         self.pg_types[oid] = in_func
 
-    def handle_ERROR_RESPONSE(self, data, ps):
+    def handle_ERROR_RESPONSE(self, data, context):
         msg = dict(
-            (s[:1].decode(self._client_encoding), s[1:].decode(self._client_encoding))
+            (
+                s[:1].decode("ascii"),
+                s[1:].decode(self._client_encoding, errors="replace"),
+            )
             for s in data.split(NULL_BYTE)
             if s != b""
         )
 
         self.error = DatabaseError(msg)
 
-    def handle_EMPTY_QUERY_RESPONSE(self, data, ps):
+    def handle_EMPTY_QUERY_RESPONSE(self, data, context):
         self.error = DatabaseError("query was empty")
 
-    def handle_CLOSE_COMPLETE(self, data, ps):
+    def handle_CLOSE_COMPLETE(self, data, context):
         pass
 
-    def handle_PARSE_COMPLETE(self, data, ps):
+    def handle_PARSE_COMPLETE(self, data, context):
         # Byte1('1') - Identifier.
         # Int32(4) - Message length, including self.
         pass
 
-    def handle_BIND_COMPLETE(self, data, ps):
+    def handle_BIND_COMPLETE(self, data, context):
         pass
 
     def handle_PORTAL_SUSPENDED(self, data, context):
         pass
 
     def handle_PARAMETER_DESCRIPTION(self, data, context):
-        """
-        ParameterDescription (B)
-
-            Byte1('t')
-
-                Identifies the message as a parameter description.
-            Int32
-
-                Length of message contents in bytes, including self.
-            Int16
-
-                The number of parameters used by the statement (can be zero).
-
-            Then, for each parameter, there is the following:
-
-            Int32
-
-                Specifies the object ID of the parameter data type.
-        """
+        """https://www.postgresql.org/docs/current/protocol-message-formats.html"""
 
         # count = h_unpack(data)[0]
         # context.parameter_oids = unpack_from("!" + "i" * count, data, 2)
 
-    def handle_COPY_DONE(self, data, ps):
-        self._copy_done = True
+    def handle_COPY_DONE(self, data, context):
+        pass
 
-    def handle_COPY_OUT_RESPONSE(self, data, ps):
-        # Int8(1) - 0 textual, 1 binary
-        # Int16(2) - Number of columns
-        # Int16(N) - Format codes for each column (0 text, 1 binary)
+    def handle_COPY_OUT_RESPONSE(self, data, context):
+        """https://www.postgresql.org/docs/current/protocol-message-formats.html"""
 
         is_binary, num_cols = bh_unpack(data)
         # column_formats = unpack_from('!' + 'h' * num_cols, data, 3)
-        if ps.stream is None:
+
+        if context.stream is None:
             raise InterfaceError(
                 "An output stream is required for the COPY OUT response."
             )
 
-    def handle_COPY_DATA(self, data, results):
-        results.stream.write(data)
+        elif isinstance(context.stream, TextIOBase):
+            if is_binary:
+                raise InterfaceError(
+                    "The COPY OUT stream is binary, but the stream parameter is text."
+                )
+            else:
+                decode = codecs.getdecoder(self._client_encoding)
 
-    def handle_COPY_IN_RESPONSE(self, data, results):
-        # Int16(2) - Number of columns
-        # Int16(N) - Format codes for each column (0 text, 1 binary)
+                def w(data):
+                    context.stream.write(decode(data)[0])
+
+                context.stream_write = w
+
+        else:
+            context.stream_write = context.stream.write
+
+    def handle_COPY_DATA(self, data, context):
+        context.stream_write(data)
+
+    def handle_COPY_IN_RESPONSE(self, data, context):
+        """https://www.postgresql.org/docs/current/protocol-message-formats.html"""
         is_binary, num_cols = bh_unpack(data)
         # column_formats = unpack_from('!' + 'h' * num_cols, data, 3)
-        if results.stream is None:
+
+        if context.stream is None:
             raise InterfaceError(
                 "An input stream is required for the COPY IN response."
             )
 
+        elif isinstance(context.stream, TextIOBase):
+            if is_binary:
+                raise InterfaceError(
+                    "The COPY IN stream is binary, but the stream parameter is text."
+                )
+
+            else:
+
+                def ri(bffr):
+                    bffr.clear()
+                    bffr.extend(context.stream.read(4096).encode(self._client_encoding))
+                    return len(bffr)
+
+                readinto = ri
+        else:
+            readinto = context.stream.readinto
+
         bffr = bytearray(8192)
         while True:
-            bytes_read = results.stream.readinto(bffr)
+            bytes_read = readinto(bffr)
             if bytes_read == 0:
                 break
-            self._write(COPY_DATA + i_pack(bytes_read + 4))
+            self._write(COPY_DATA)
+            self._write(i_pack(bytes_read + 4))
             self._write(bffr[:bytes_read])
             self._flush()
 
         # Send CopyDone
-        # Byte1('c') - Identifier.
-        # Int32(4) - Message length, including self.
         self._write(COPY_DONE_MSG)
         self._write(SYNC_MSG)
         self._flush()
 
-    def handle_NOTIFICATION_RESPONSE(self, data, results):
-        ##
-        # A message sent if this connection receives a NOTIFY that it was
-        # LISTENing for.
-        # <p>
-        # Stability: Added in pg8000 v1.03.  When limited to accessing
-        # properties from a notification event dispatch, stability is
-        # guaranteed for v1.xx.
+    def handle_NOTIFICATION_RESPONSE(self, data, context):
+        """https://www.postgresql.org/docs/current/protocol-message-formats.html"""
         backend_pid = i_unpack(data)[0]
         idx = 4
         null_idx = data.find(NULL_BYTE, idx)
@@ -465,8 +476,6 @@ class CoreConnection:
         <http://www.python.org/dev/peps/pep-0249/>`_.
         """
         try:
-            # Byte1('X') - Identifies the message as a terminate message.
-            # Int32(4) - Message length, including self.
             self._write(TERMINATE_MSG)
             self._flush()
             self._sock.close()
@@ -481,20 +490,8 @@ class CoreConnection:
             self._sock = None
 
     def handle_AUTHENTICATION_REQUEST(self, data, context):
-        # Int32 -   An authentication code that represents different
-        #           authentication messages:
-        #               0 = AuthenticationOk
-        #               5 = MD5 pwd
-        #               2 = Kerberos v5 (not supported by pg8000)
-        #               3 = Cleartext pwd
-        #               4 = crypt() pwd (not supported by pg8000)
-        #               6 = SCM credential (not supported by pg8000)
-        #               7 = GSSAPI (not supported by pg8000)
-        #               8 = GSSAPI data (not supported by pg8000)
-        #               9 = SSPI (not supported by pg8000)
-        # Some authentication messages have additional data following the
-        # authentication code.  That data is documented in the appropriate
-        # class.
+        """https://www.postgresql.org/docs/current/protocol-message-formats.html"""
+
         auth_code = i_unpack(data)[0]
         if auth_code == 0:
             pass
@@ -506,14 +503,8 @@ class CoreConnection:
                 )
             self._send_message(PASSWORD, self.password + NULL_BYTE)
             self._flush()
-        elif auth_code == 5:
-            ##
-            # A message representing the backend requesting an MD5 hashed
-            # password response.  The response will be sent as
-            # md5(md5(pwd + login) + salt).
 
-            # Additional message data:
-            #  Byte4 - Hash salt.
+        elif auth_code == 5:
             salt = b"".join(cccc_unpack(data, 4))
             if self.password is None:
                 raise InterfaceError(
@@ -523,9 +514,6 @@ class CoreConnection:
             pwd = b"md5" + md5(
                 md5(self.password + self.user).hexdigest().encode("ascii") + salt
             ).hexdigest().encode("ascii")
-            # Byte1('p') - Identifies the message as a password message.
-            # Int32 - Message length including self.
-            # String - The password.  Password may be encrypted.
             self._send_message(PASSWORD, pwd + NULL_BYTE)
             self._flush()
 
@@ -544,7 +532,7 @@ class CoreConnection:
             mech = self.auth.mechanism_name.encode("ascii") + NULL_BYTE
 
             # SASLInitialResponse
-            self._write(create_message(PASSWORD, mech + i_pack(len(init)) + init))
+            self._send_message(PASSWORD, mech + i_pack(len(init)) + init)
             self._flush()
 
         elif auth_code == 11:
@@ -553,7 +541,7 @@ class CoreConnection:
 
             # SASLResponse
             msg = self.auth.get_client_final().encode("utf8")
-            self._write(create_message(PASSWORD, msg))
+            self._send_message(PASSWORD, msg)
             self._flush()
 
         elif auth_code == 12:
@@ -569,11 +557,10 @@ class CoreConnection:
                 f"Authentication method {auth_code} not recognized by pg8000."
             )
 
-    def handle_READY_FOR_QUERY(self, data, ps):
-        # Byte1 -   Status indicator.
+    def handle_READY_FOR_QUERY(self, data, context):
         self.in_transaction = data != IDLE
 
-    def handle_BACKEND_KEY_DATA(self, data, ps):
+    def handle_BACKEND_KEY_DATA(self, data, context):
         self._backend_key_data = data
 
     def handle_ROW_DESCRIPTION(self, data, context):
@@ -604,8 +591,10 @@ class CoreConnection:
 
         context.columns = columns
         context.input_funcs = input_funcs
+        if context.rows is None:
+            context.rows = []
 
-    def send_PARSE(self, statement_name_bin, statement, oids):
+    def send_PARSE(self, statement_name_bin, statement, oids=()):
 
         val = bytearray(statement_name_bin)
         val.extend(statement.encode(self._client_encoding) + NULL_BYTE)
@@ -621,63 +610,50 @@ class CoreConnection:
         self._write(FLUSH_MSG)
 
     def send_QUERY(self, sql):
-        data = sql.encode(self._client_encoding) + NULL_BYTE
-        try:
-            self._write(QUERY)
-            self._write(i_pack(len(data) + 4))
-            self._write(data)
-        except ValueError as e:
-            if str(e) == "write to closed file":
-                raise InterfaceError("connection is closed")
-            else:
-                raise e
-        except AttributeError:
-            raise InterfaceError("connection is closed")
+        self._send_message(QUERY, sql.encode(self._client_encoding) + NULL_BYTE)
 
-    def execute_unnamed(self, statement, vals=(), input_oids=None, stream=None):
-        context = Context(stream=stream)
+    def execute_simple(self, statement):
+        context = Context()
 
-        if len(vals) == 0 and stream is None:
-            self.send_QUERY(statement)
-            self._flush()
-            self.handle_messages(context)
-        else:
-            param_oids, params = make_params(self.py_types, vals)
-            if input_oids is None:
-                oids = param_oids
-            else:
-                oids = [(p if i is None else i) for p, i in zip(param_oids, input_oids)]
-
-            self.send_PARSE(NULL_BYTE, statement, oids)
-            self._write(SYNC_MSG)
-            self._flush()
-            self.handle_messages(context)
-            self.send_DESCRIBE_STATEMENT(NULL_BYTE)
-
-            self._write(SYNC_MSG)
-
-            try:
-                self._flush()
-            except AttributeError as e:
-                if self._sock is None:
-                    raise InterfaceError("connection is closed")
-                else:
-                    raise e
-
-            self.send_BIND(NULL_BYTE, params)
-            self.handle_messages(context)
-            self.send_EXECUTE()
-
-            self._write(SYNC_MSG)
-            self._flush()
-            self.handle_messages(context)
+        self.send_QUERY(statement)
+        self._flush()
+        self.handle_messages(context)
 
         return context
 
-    def prepare_statement(self, statement, oids):
+    def execute_unnamed(self, statement, vals=(), oids=(), stream=None):
+        context = Context(stream=stream)
+
+        self.send_PARSE(NULL_BYTE, statement, oids)
+        self._write(SYNC_MSG)
+        self._flush()
+        self.handle_messages(context)
+        self.send_DESCRIBE_STATEMENT(NULL_BYTE)
+
+        self._write(SYNC_MSG)
+
+        try:
+            self._flush()
+        except AttributeError as e:
+            if self._sock is None:
+                raise InterfaceError("connection is closed")
+            else:
+                raise e
+        params = make_params(self.py_types, vals)
+        self.send_BIND(NULL_BYTE, params)
+        self.handle_messages(context)
+        self.send_EXECUTE()
+
+        self._write(SYNC_MSG)
+        self._flush()
+        self.handle_messages(context)
+
+        return context
+
+    def prepare_statement(self, statement, oids=None):
 
         for i in count():
-            statement_name = "_".join(("pg8000", "statement", str(i)))
+            statement_name = f"pg8000_statement_{i}"
             statement_name_bin = statement_name.encode("ascii") + NULL_BYTE
             if statement_name_bin not in self._statement_nums:
                 self._statement_nums.add(statement_name_bin)
@@ -724,23 +700,8 @@ class CoreConnection:
             raise InterfaceError("connection is closed")
 
     def send_BIND(self, statement_name_bin, params):
+        """https://www.postgresql.org/docs/current/protocol-message-formats.html"""
 
-        # Byte1('B') - Identifies the Bind command.
-        # Int32 - Message length, including self.
-        # String - Name of the destination portal.
-        # String - Name of the source prepared statement.
-        # Int16 - Number of parameter format codes.
-        # For each parameter format code:
-        #   Int16 - The parameter format code.
-        # Int16 - Number of parameter values.
-        # For each parameter value:
-        #   Int32 - The length of the parameter value, in bytes, not
-        #           including this length.  -1 indicates a NULL parameter
-        #           value, in which no value bytes follow.
-        #   Byte[n] - Value of the parameter.
-        # Int16 - The number of result-column format codes.
-        # For each result-column format code:
-        #   Int16 - The format code.
         retval = bytearray(
             NULL_BYTE + statement_name_bin + h_pack(0) + h_pack(len(params))
         )
@@ -758,32 +719,28 @@ class CoreConnection:
         self._write(FLUSH_MSG)
 
     def send_EXECUTE(self):
-        # Byte1('E') - Identifies the message as an execute message.
-        # Int32 -   Message length, including self.
-        # String -  The name of the portal to execute.
-        # Int32 -   Maximum number of rows to return, if portal
-        #           contains a query # that returns rows.
-        #           0 = no limit.
+        """https://www.postgresql.org/docs/current/protocol-message-formats.html"""
         self._write(EXECUTE_MSG)
         self._write(FLUSH_MSG)
 
     def handle_NO_DATA(self, msg, context):
-        context.columns = []
+        pass
 
     def handle_COMMAND_COMPLETE(self, data, context):
         values = data[:-1].split(b" ")
-        command = values[0]
-        if command in self._commands_with_count:
+        try:
             row_count = int(values[-1])
             if context.row_count == -1:
                 context.row_count = row_count
             else:
                 context.row_count += row_count
+        except ValueError:
+            pass
 
-    def handle_DATA_ROW(self, data, results):
+    def handle_DATA_ROW(self, data, context):
         idx = 2
         row = []
-        for func in results.input_funcs:
+        for func in context.input_funcs:
             vlen = i_unpack(data, idx)[0]
             idx += 4
             if vlen == -1:
@@ -792,7 +749,7 @@ class CoreConnection:
                 v = func(str(data[idx : idx + vlen], encoding=self._client_encoding))
                 idx += vlen
             row.append(v)
-        results.rows.append(row)
+        context.rows.append(row)
 
     def handle_messages(self, context):
         code = self.error = None
@@ -809,11 +766,8 @@ class CoreConnection:
         if self.error is not None:
             raise self.error
 
-    # Byte1('C') - Identifies the message as a close command.
-    # Int32 - Message length, including self.
-    # Byte1 - 'S' for prepared statement, 'P' for portal.
-    # String - The name of the item to close.
     def close_prepared_statement(self, statement_name_bin):
+        """https://www.postgresql.org/docs/current/protocol-message-formats.html"""
         self._send_message(CLOSE, STATEMENT + statement_name_bin)
         self._write(FLUSH_MSG)
         self._write(SYNC_MSG)
@@ -822,15 +776,11 @@ class CoreConnection:
         self.handle_messages(context)
         self._statement_nums.remove(statement_name_bin)
 
-    # Byte1('N') - Identifier
-    # Int32 - Message length
-    # Any number of these, followed by a zero byte:
-    #   Byte1 - code identifying the field type (see responseKeys)
-    #   String - field value
-    def handle_NOTICE_RESPONSE(self, data, ps):
+    def handle_NOTICE_RESPONSE(self, data, context):
+        """https://www.postgresql.org/docs/current/protocol-message-formats.html"""
         self.notices.append(dict((s[0:1], s[1:]) for s in data.split(NULL_BYTE)))
 
-    def handle_PARAMETER_STATUS(self, data, ps):
+    def handle_PARAMETER_STATUS(self, data, context):
         pos = data.find(NULL_BYTE)
         key, value = data[:pos], data[pos + 1 : -1]
         self.parameter_statuses.append((key, value))
@@ -846,24 +796,13 @@ class CoreConnection:
                 pass
 
         elif key == b"server_version":
-            self._server_version = LooseVersion(value.decode("ascii"))
-            if self._server_version < LooseVersion("8.2.0"):
-                self._commands_with_count = (b"INSERT", b"DELETE", b"UPDATE", b"MOVE")
-            elif self._server_version < LooseVersion("9.0.0"):
-                self._commands_with_count = (
-                    b"INSERT",
-                    b"DELETE",
-                    b"UPDATE",
-                    b"MOVE",
-                    b"FETCH",
-                    b"COPY",
-                )
+            pass
 
 
 class Context:
     def __init__(self, stream=None, columns=None, input_funcs=None):
-        self.rows = []
+        self.rows = None if columns is None else []
         self.row_count = -1
-        self.columns = [] if columns is None else columns
+        self.columns = columns
         self.stream = stream
         self.input_funcs = [] if input_funcs is None else input_funcs
