@@ -1,10 +1,11 @@
 import time
 import warnings
 
+import pytest
+
 import pg8000
 
-import pytest
-''' Python DB API 2.0 driver compliance unit test suite.
+""" Python DB API 2.0 driver compliance unit test suite.
 
     This software is Public Domain and may be used without restrictions.
 
@@ -14,11 +15,11 @@ import pytest
   this is turning out to be a thoroughly unwholesome unit test."
 
     -- Ian Bicking
-'''
+"""
 
-__rcs_id__ = '$Id: dbapi20.py,v 1.10 2003/10/09 03:14:14 zenzen Exp $'
-__version__ = '$Revision: 1.10 $'[11:-2]
-__author__ = 'Stuart Bishop <zen@shangri-la.dropbear.id.au>'
+__rcs_id__ = "$Id: dbapi20.py,v 1.10 2003/10/09 03:14:14 zenzen Exp $"
+__version__ = "$Revision: 1.10 $"[11:-2]
+__author__ = "Stuart Bishop <zen@shangri-la.dropbear.id.au>"
 
 
 # $Log: dbapi20.py,v $
@@ -65,7 +66,7 @@ __author__ = 'Stuart Bishop <zen@shangri-la.dropbear.id.au>'
 #
 
 
-''' Test a database self.driver for DB API 2.0 compatibility.
+""" Test a database self.driver for DB API 2.0 compatibility.
     This implementation tests Gadfly, but the TestCase
     is structured so that other self.drivers can subclass this
     test case to ensure compiliance with the DB-API. It is
@@ -84,21 +85,21 @@ __author__ = 'Stuart Bishop <zen@shangri-la.dropbear.id.au>'
 
     Don't 'import DatabaseAPI20Test from dbapi20', or you will
     confuse the unit tester - just 'import dbapi20'.
-'''
+"""
 
 # The self.driver module. This should be the module where the 'connect'
 # method is to be found
 driver = pg8000
-table_prefix = 'dbapi20test_'  # If you need to specify a prefix for tables
+table_prefix = "dbapi20test_"  # If you need to specify a prefix for tables
 
-ddl1 = 'create table %sbooze (name varchar(20))' % table_prefix
-ddl2 = 'create table %sbarflys (name varchar(20))' % table_prefix
-xddl1 = 'drop table %sbooze' % table_prefix
-xddl2 = 'drop table %sbarflys' % table_prefix
+ddl1 = "create table %sbooze (name varchar(20))" % table_prefix
+ddl2 = "create table %sbarflys (name varchar(20))" % table_prefix
+xddl1 = "drop table %sbooze" % table_prefix
+xddl2 = "drop table %sbarflys" % table_prefix
 
 # Name of stored procedure to convert
 # string->lowercase
-lowerfunc = 'lower'
+lowerfunc = "lower"
 
 
 # Some drivers may need to override these helpers, for example adding
@@ -133,7 +134,7 @@ def test_apilevel():
     apilevel = driver.apilevel
 
     # Must equal 2.0
-    assert apilevel == '2.0'
+    assert apilevel == "2.0"
 
 
 def test_threadsafety():
@@ -151,8 +152,7 @@ def test_paramstyle():
         # Must exist
         paramstyle = driver.paramstyle
         # Must be a valid value
-        assert paramstyle in (
-            'qmark', 'numeric', 'named', 'format', 'pyformat')
+        assert paramstyle in ("qmark", "numeric", "named", "format", "pyformat")
     except AttributeError:
         assert False, "Driver doesn't define paramstyle"
 
@@ -200,7 +200,7 @@ def test_commit(con):
 def test_rollback(con):
     # If rollback is defined, it should either work or throw
     # the documented exception
-    if hasattr(con, 'rollback'):
+    if hasattr(con, "rollback"):
         try:
             con.rollback()
         except driver.NotSupportedError:
@@ -217,57 +217,61 @@ def test_cursor_isolation(con):
     cur1 = con.cursor()
     cur2 = con.cursor()
     executeDDL1(cur1)
-    cur1.execute(
-        "insert into %sbooze values ('Victoria Bitter')" % (table_prefix))
+    cur1.execute("insert into %sbooze values ('Victoria Bitter')" % (table_prefix))
     cur2.execute("select name from %sbooze" % table_prefix)
     booze = cur2.fetchall()
     assert len(booze) == 1
     assert len(booze[0]) == 1
-    assert booze[0][0] == 'Victoria Bitter'
+    assert booze[0][0] == "Victoria Bitter"
 
 
 def test_description(con):
     cur = con.cursor()
     executeDDL1(cur)
-    assert cur.description is None, \
-        'cursor.description should be none after executing a ' \
-        'statement that can return no rows (such as DDL)'
-    cur.execute('select name from %sbooze' % table_prefix)
-    assert len(cur.description) == 1, \
-        'cursor.description describes too many columns'
-    assert len(cur.description[0]) == 7, \
-        'cursor.description[x] tuples must have 7 elements'
-    assert cur.description[0][0].lower() == 'name', \
-        'cursor.description[x][0] must return column name'
-    assert cur.description[0][1] == driver.STRING, \
-        'cursor.description[x][1] must return column type. Got %r' \
+    assert cur.description is None, (
+        "cursor.description should be none after executing a "
+        "statement that can return no rows (such as DDL)"
+    )
+    cur.execute("select name from %sbooze" % table_prefix)
+    assert len(cur.description) == 1, "cursor.description describes too many columns"
+    assert (
+        len(cur.description[0]) == 7
+    ), "cursor.description[x] tuples must have 7 elements"
+    assert (
+        cur.description[0][0].lower() == "name"
+    ), "cursor.description[x][0] must return column name"
+    assert cur.description[0][1] == driver.STRING, (
+        "cursor.description[x][1] must return column type. Got %r"
         % cur.description[0][1]
+    )
 
     # Make sure self.description gets reset
     executeDDL2(cur)
-    assert cur.description is None, \
-        'cursor.description not being set to None when executing ' \
-        'no-result statements (eg. DDL)'
+    assert cur.description is None, (
+        "cursor.description not being set to None when executing "
+        "no-result statements (eg. DDL)"
+    )
 
 
 def test_rowcount(cursor):
     executeDDL1(cursor)
-    assert cursor.rowcount == -1, \
-        'cursor.rowcount should be -1 after executing no-result ' \
-        'statements'
-    cursor.execute(
-        "insert into %sbooze values ('Victoria Bitter')" % (table_prefix))
-    assert cursor.rowcount in (-1, 1), \
-        'cursor.rowcount should == number or rows inserted, or ' \
-        'set to -1 after executing an insert statement'
+    assert cursor.rowcount == -1, (
+        "cursor.rowcount should be -1 after executing no-result " "statements"
+    )
+    cursor.execute("insert into %sbooze values ('Victoria Bitter')" % (table_prefix))
+    assert cursor.rowcount in (-1, 1), (
+        "cursor.rowcount should == number or rows inserted, or "
+        "set to -1 after executing an insert statement"
+    )
     cursor.execute("select name from %sbooze" % table_prefix)
-    assert cursor.rowcount in (-1, 1), \
-        'cursor.rowcount should == number of rows returned, or ' \
-        'set to -1 after executing a select statement'
+    assert cursor.rowcount in (-1, 1), (
+        "cursor.rowcount should == number of rows returned, or "
+        "set to -1 after executing a select statement"
+    )
     executeDDL2(cursor)
-    assert cursor.rowcount == -1, \
-        'cursor.rowcount not being reset to -1 after executing ' \
-        'no-result statements'
+    assert cursor.rowcount == -1, (
+        "cursor.rowcount not being reset to -1 after executing " "no-result statements"
+    )
 
 
 def test_close(con):
@@ -296,78 +300,73 @@ def test_execute(con):
 
 def _paraminsert(cur):
     executeDDL1(cur)
-    cur.execute(
-        "insert into %sbooze values ('Victoria Bitter')" % (table_prefix))
+    cur.execute("insert into %sbooze values ('Victoria Bitter')" % (table_prefix))
     assert cur.rowcount in (-1, 1)
 
-    if driver.paramstyle == 'qmark':
+    if driver.paramstyle == "qmark":
+        cur.execute("insert into %sbooze values (?)" % table_prefix, ("Cooper's",))
+    elif driver.paramstyle == "numeric":
+        cur.execute("insert into %sbooze values (:1)" % table_prefix, ("Cooper's",))
+    elif driver.paramstyle == "named":
         cur.execute(
-            'insert into %sbooze values (?)' % table_prefix, ("Cooper's",))
-    elif driver.paramstyle == 'numeric':
+            "insert into %sbooze values (:beer)" % table_prefix, {"beer": "Cooper's"}
+        )
+    elif driver.paramstyle == "format":
+        cur.execute("insert into %sbooze values (%%s)" % table_prefix, ("Cooper's",))
+    elif driver.paramstyle == "pyformat":
         cur.execute(
-            'insert into %sbooze values (:1)' % table_prefix, ("Cooper's",))
-    elif driver.paramstyle == 'named':
-        cur.execute(
-            'insert into %sbooze values (:beer)' % table_prefix,
-            {'beer': "Cooper's"})
-    elif driver.paramstyle == 'format':
-        cur.execute(
-            'insert into %sbooze values (%%s)' % table_prefix, ("Cooper's",))
-    elif driver.paramstyle == 'pyformat':
-        cur.execute(
-            'insert into %sbooze values (%%(beer)s)' % table_prefix,
-            {'beer': "Cooper's"})
+            "insert into %sbooze values (%%(beer)s)" % table_prefix,
+            {"beer": "Cooper's"},
+        )
     else:
-        assert False, 'Invalid paramstyle'
+        assert False, "Invalid paramstyle"
 
     assert cur.rowcount in (-1, 1)
 
-    cur.execute('select name from %sbooze' % table_prefix)
+    cur.execute("select name from %sbooze" % table_prefix)
     res = cur.fetchall()
-    assert len(res) == 2, 'cursor.fetchall returned too few rows'
+    assert len(res) == 2, "cursor.fetchall returned too few rows"
     beers = [res[0][0], res[1][0]]
     beers.sort()
-    assert beers[0] == "Cooper's", \
-        'cursor.fetchall retrieved incorrect data, or data inserted ' \
-        'incorrectly'
-    assert beers[1] == "Victoria Bitter", \
-        'cursor.fetchall retrieved incorrect data, or data inserted ' \
-        'incorrectly'
+    assert beers[0] == "Cooper's", (
+        "cursor.fetchall retrieved incorrect data, or data inserted " "incorrectly"
+    )
+    assert beers[1] == "Victoria Bitter", (
+        "cursor.fetchall retrieved incorrect data, or data inserted " "incorrectly"
+    )
 
 
 def test_executemany(cursor):
     executeDDL1(cursor)
     largs = [("Cooper's",), ("Boag's",)]
-    margs = [{'beer': "Cooper's"}, {'beer': "Boag's"}]
-    if driver.paramstyle == 'qmark':
+    margs = [{"beer": "Cooper's"}, {"beer": "Boag's"}]
+    if driver.paramstyle == "qmark":
+        cursor.executemany("insert into %sbooze values (?)" % table_prefix, largs)
+    elif driver.paramstyle == "numeric":
+        cursor.executemany("insert into %sbooze values (:1)" % table_prefix, largs)
+    elif driver.paramstyle == "named":
+        cursor.executemany("insert into %sbooze values (:beer)" % table_prefix, margs)
+    elif driver.paramstyle == "format":
+        cursor.executemany("insert into %sbooze values (%%s)" % table_prefix, largs)
+    elif driver.paramstyle == "pyformat":
         cursor.executemany(
-            'insert into %sbooze values (?)' % table_prefix, largs)
-    elif driver.paramstyle == 'numeric':
-        cursor.executemany(
-            'insert into %sbooze values (:1)' % table_prefix, largs)
-    elif driver.paramstyle == 'named':
-        cursor.executemany(
-            'insert into %sbooze values (:beer)' % table_prefix, margs)
-    elif driver.paramstyle == 'format':
-        cursor.executemany(
-            'insert into %sbooze values (%%s)' % table_prefix, largs)
-    elif driver.paramstyle == 'pyformat':
-        cursor.executemany(
-            'insert into %sbooze values (%%(beer)s)' % (table_prefix), margs)
+            "insert into %sbooze values (%%(beer)s)" % (table_prefix), margs
+        )
     else:
-        assert False, 'Unknown paramstyle'
+        assert False, "Unknown paramstyle"
 
-    assert cursor.rowcount in (-1, 2), \
-        'insert using cursor.executemany set cursor.rowcount to ' \
-        'incorrect value %r' % cursor.rowcount
+    assert cursor.rowcount in (-1, 2), (
+        "insert using cursor.executemany set cursor.rowcount to "
+        "incorrect value %r" % cursor.rowcount
+    )
 
-    cursor.execute('select name from %sbooze' % table_prefix)
+    cursor.execute("select name from %sbooze" % table_prefix)
     res = cursor.fetchall()
-    assert len(res) == 2, 'cursor.fetchall retrieved incorrect number of rows'
+    assert len(res) == 2, "cursor.fetchall retrieved incorrect number of rows"
     beers = [res[0][0], res[1][0]]
     beers.sort()
-    assert beers[0] == "Boag's", 'incorrect data retrieved'
-    assert beers[1] == "Cooper's", 'incorrect data retrieved'
+    assert beers[0] == "Boag's", "incorrect data retrieved"
+    assert beers[1] == "Cooper's", "incorrect data retrieved"
 
 
 def test_fetchone(cursor):
@@ -382,46 +381,45 @@ def test_fetchone(cursor):
     with pytest.raises(driver.Error):
         cursor.fetchone()
 
-    cursor.execute('select name from %sbooze' % table_prefix)
-    assert cursor.fetchone() is None, \
-        'cursor.fetchone should return None if a query retrieves ' \
-        'no rows'
+    cursor.execute("select name from %sbooze" % table_prefix)
+    assert cursor.fetchone() is None, (
+        "cursor.fetchone should return None if a query retrieves " "no rows"
+    )
     assert cursor.rowcount in (-1, 0)
 
     # cursor.fetchone should raise an Error if called after
     # executing a query that cannnot return rows
-    cursor.execute(
-        "insert into %sbooze values ('Victoria Bitter')" % (table_prefix))
+    cursor.execute("insert into %sbooze values ('Victoria Bitter')" % (table_prefix))
     with pytest.raises(driver.Error):
         cursor.fetchone()
 
-    cursor.execute('select name from %sbooze' % table_prefix)
+    cursor.execute("select name from %sbooze" % table_prefix)
     r = cursor.fetchone()
-    assert len(r) == 1, 'cursor.fetchone should have retrieved a single row'
-    assert r[0] == 'Victoria Bitter', \
-        'cursor.fetchone retrieved incorrect data'
-    assert cursor.fetchone() is None, \
-        'cursor.fetchone should return None if no more rows available'
+    assert len(r) == 1, "cursor.fetchone should have retrieved a single row"
+    assert r[0] == "Victoria Bitter", "cursor.fetchone retrieved incorrect data"
+    assert (
+        cursor.fetchone() is None
+    ), "cursor.fetchone should return None if no more rows available"
     assert cursor.rowcount in (-1, 1)
 
 
 samples = [
-    'Carlton Cold',
-    'Carlton Draft',
-    'Mountain Goat',
-    'Redback',
-    'Victoria Bitter',
-    'XXXX'
+    "Carlton Cold",
+    "Carlton Draft",
+    "Mountain Goat",
+    "Redback",
+    "Victoria Bitter",
+    "XXXX",
 ]
 
 
 def _populate():
-    ''' Return a list of sql commands to setup the DB for the fetch
-        tests.
-    '''
+    """Return a list of sql commands to setup the DB for the fetch
+    tests.
+    """
     populate = [
-        "insert into %sbooze values ('%s')" % (table_prefix, s)
-        for s in samples]
+        "insert into %sbooze values ('%s')" % (table_prefix, s) for s in samples
+    ]
     return populate
 
 
@@ -435,27 +433,29 @@ def test_fetchmany(cursor):
     for sql in _populate():
         cursor.execute(sql)
 
-    cursor.execute('select name from %sbooze' % table_prefix)
+    cursor.execute("select name from %sbooze" % table_prefix)
     r = cursor.fetchmany()
-    assert len(r) == 1, \
-        'cursor.fetchmany retrieved incorrect number of rows, ' \
-        'default of arraysize is one.'
+    assert len(r) == 1, (
+        "cursor.fetchmany retrieved incorrect number of rows, "
+        "default of arraysize is one."
+    )
     cursor.arraysize = 10
     r = cursor.fetchmany(3)  # Should get 3 rows
-    assert len(r) == 3, 'cursor.fetchmany retrieved incorrect number of rows'
+    assert len(r) == 3, "cursor.fetchmany retrieved incorrect number of rows"
     r = cursor.fetchmany(4)  # Should get 2 more
-    assert len(r) == 2, 'cursor.fetchmany retrieved incorrect number of rows'
+    assert len(r) == 2, "cursor.fetchmany retrieved incorrect number of rows"
     r = cursor.fetchmany(4)  # Should be an empty sequence
-    assert len(r) == 0, \
-        'cursor.fetchmany should return an empty sequence after ' \
-        'results are exhausted'
+    assert len(r) == 0, (
+        "cursor.fetchmany should return an empty sequence after "
+        "results are exhausted"
+    )
     assert cursor.rowcount in (-1, 6)
 
     # Same as above, using cursor.arraysize
     cursor.arraysize = 4
-    cursor.execute('select name from %sbooze' % table_prefix)
+    cursor.execute("select name from %sbooze" % table_prefix)
     r = cursor.fetchmany()  # Should get 4 rows
-    assert len(r) == 4, 'cursor.arraysize not being honoured by fetchmany'
+    assert len(r) == 4, "cursor.arraysize not being honoured by fetchmany"
     r = cursor.fetchmany()  # Should get 2 more
     assert len(r) == 2
     r = cursor.fetchmany()  # Should be an empty sequence
@@ -463,7 +463,7 @@ def test_fetchmany(cursor):
     assert cursor.rowcount in (-1, 6)
 
     cursor.arraysize = 6
-    cursor.execute('select name from %sbooze' % table_prefix)
+    cursor.execute("select name from %sbooze" % table_prefix)
     rows = cursor.fetchmany()  # Should get all rows
     assert cursor.rowcount in (-1, 6)
     assert len(rows) == 6
@@ -473,21 +473,21 @@ def test_fetchmany(cursor):
 
     # Make sure we get the right data back out
     for i in range(0, 6):
-        assert rows[i] == samples[i], \
-            'incorrect data retrieved by cursor.fetchmany'
+        assert rows[i] == samples[i], "incorrect data retrieved by cursor.fetchmany"
 
     rows = cursor.fetchmany()  # Should return an empty list
-    assert len(rows) == 0, \
-        'cursor.fetchmany should return an empty sequence if ' \
-        'called after the whole result set has been fetched'
+    assert len(rows) == 0, (
+        "cursor.fetchmany should return an empty sequence if "
+        "called after the whole result set has been fetched"
+    )
     assert cursor.rowcount in (-1, 6)
 
     executeDDL2(cursor)
-    cursor.execute('select name from %sbarflys' % table_prefix)
+    cursor.execute("select name from %sbarflys" % table_prefix)
     r = cursor.fetchmany()  # Should get empty sequence
-    assert len(r) == 0, \
-        'cursor.fetchmany should return an empty sequence if ' \
-        'query retrieved no rows'
+    assert len(r) == 0, (
+        "cursor.fetchmany should return an empty sequence if " "query retrieved no rows"
+    )
     assert cursor.rowcount in (-1, 0)
 
 
@@ -507,29 +507,29 @@ def test_fetchall(cursor):
     with pytest.raises(driver.Error):
         cursor.fetchall()
 
-    cursor.execute('select name from %sbooze' % table_prefix)
+    cursor.execute("select name from %sbooze" % table_prefix)
     rows = cursor.fetchall()
     assert cursor.rowcount in (-1, len(samples))
-    assert len(rows) == len(samples), \
-        'cursor.fetchall did not retrieve all rows'
+    assert len(rows) == len(samples), "cursor.fetchall did not retrieve all rows"
     rows = [r[0] for r in rows]
     rows.sort()
     for i in range(0, len(samples)):
-        assert rows[i] == samples[i], \
-            'cursor.fetchall retrieved incorrect rows'
+        assert rows[i] == samples[i], "cursor.fetchall retrieved incorrect rows"
     rows = cursor.fetchall()
-    assert len(rows) == 0, \
-        'cursor.fetchall should return an empty list if called ' \
-        'after the whole result set has been fetched'
+    assert len(rows) == 0, (
+        "cursor.fetchall should return an empty list if called "
+        "after the whole result set has been fetched"
+    )
     assert cursor.rowcount in (-1, len(samples))
 
     executeDDL2(cursor)
-    cursor.execute('select name from %sbarflys' % table_prefix)
+    cursor.execute("select name from %sbarflys" % table_prefix)
     rows = cursor.fetchall()
     assert cursor.rowcount in (-1, 0)
-    assert len(rows) == 0, \
-        'cursor.fetchall should return an empty list if ' \
-        'a select query returns no rows'
+    assert len(rows) == 0, (
+        "cursor.fetchall should return an empty list if "
+        "a select query returns no rows"
+    )
 
 
 def test_mixedfetch(cursor):
@@ -537,14 +537,14 @@ def test_mixedfetch(cursor):
     for sql in _populate():
         cursor.execute(sql)
 
-    cursor.execute('select name from %sbooze' % table_prefix)
+    cursor.execute("select name from %sbooze" % table_prefix)
     rows1 = cursor.fetchone()
     rows23 = cursor.fetchmany(2)
     rows4 = cursor.fetchone()
     rows56 = cursor.fetchall()
     assert cursor.rowcount in (-1, 6)
-    assert len(rows23) == 2, 'fetchmany returned incorrect number of rows'
-    assert len(rows56) == 2, 'fetchall returned incorrect number of rows'
+    assert len(rows23) == 2, "fetchmany returned incorrect number of rows"
+    assert len(rows56) == 2, "fetchall returned incorrect number of rows"
 
     rows = [rows1[0]]
     rows.extend([rows23[0][0], rows23[1][0]])
@@ -552,24 +552,24 @@ def test_mixedfetch(cursor):
     rows.extend([rows56[0][0], rows56[1][0]])
     rows.sort()
     for i in range(0, len(samples)):
-        assert rows[i] == samples[i], 'incorrect data retrieved or inserted'
+        assert rows[i] == samples[i], "incorrect data retrieved or inserted"
 
 
 def help_nextset_setUp(cur):
-    ''' Should create a procedure called deleteme
-        that returns two result sets, first the
-        number of rows in booze then "name from booze"
-    '''
-    raise NotImplementedError('Helper not implemented')
+    """Should create a procedure called deleteme
+    that returns two result sets, first the
+    number of rows in booze then "name from booze"
+    """
+    raise NotImplementedError("Helper not implemented")
 
 
 def help_nextset_tearDown(cur):
-    'If cleaning up is needed after nextSetTest'
-    raise NotImplementedError('Helper not implemented')
+    "If cleaning up is needed after nextSetTest"
+    raise NotImplementedError("Helper not implemented")
 
 
 def test_nextset(cursor):
-    if not hasattr(cursor, 'nextset'):
+    if not hasattr(cursor, "nextset"):
         return
 
     try:
@@ -580,21 +580,21 @@ def test_nextset(cursor):
 
         help_nextset_setUp(cursor)
 
-        cursor.callproc('deleteme')
+        cursor.callproc("deleteme")
         numberofrows = cursor.fetchone()
         assert numberofrows[0] == len(samples)
         assert cursor.nextset()
         names = cursor.fetchall()
         assert len(names) == len(samples)
         s = cursor.nextset()
-        assert s is None, 'No more return sets, should return None'
+        assert s is None, "No more return sets, should return None"
     finally:
         help_nextset_tearDown(cursor)
 
 
 def test_arraysize(cursor):
     # Not much here - rest of the tests for this are in test_fetchmany
-    assert hasattr(cursor, 'arraysize'), 'cursor.arraysize must be defined'
+    assert hasattr(cursor, "arraysize"), "cursor.arraysize must be defined"
 
 
 def test_setinputsizes(cursor):
@@ -610,12 +610,12 @@ def test_setoutputsize_basic(cursor):
 
 def test_None(cursor):
     executeDDL1(cursor)
-    cursor.execute('insert into %sbooze values (NULL)' % table_prefix)
-    cursor.execute('select name from %sbooze' % table_prefix)
+    cursor.execute("insert into %sbooze values (NULL)" % table_prefix)
+    cursor.execute("select name from %sbooze" % table_prefix)
     r = cursor.fetchall()
     assert len(r) == 1
     assert len(r[0]) == 1
-    assert r[0][0] is None, 'NULL value not returned as None'
+    assert r[0][0] is None, "NULL value not returned as None"
 
 
 def test_Date():
@@ -640,25 +640,25 @@ def test_Timestamp():
 
 
 def test_Binary():
-    driver.Binary(b'Something')
-    driver.Binary(b'')
+    driver.Binary(b"Something")
+    driver.Binary(b"")
 
 
 def test_STRING():
-    assert hasattr(driver, 'STRING'), 'module.STRING must be defined'
+    assert hasattr(driver, "STRING"), "module.STRING must be defined"
 
 
 def test_BINARY():
-    assert hasattr(driver, 'BINARY'), 'module.BINARY must be defined.'
+    assert hasattr(driver, "BINARY"), "module.BINARY must be defined."
 
 
 def test_NUMBER():
-    assert hasattr(driver, 'NUMBER'), 'module.NUMBER must be defined.'
+    assert hasattr(driver, "NUMBER"), "module.NUMBER must be defined."
 
 
 def test_DATETIME():
-    assert hasattr(driver, 'DATETIME'), 'module.DATETIME must be defined.'
+    assert hasattr(driver, "DATETIME"), "module.DATETIME must be defined."
 
 
 def test_ROWID():
-    assert hasattr(driver, 'ROWID'), 'module.ROWID must be defined.'
+    assert hasattr(driver, "ROWID"), "module.ROWID must be defined."
