@@ -1,23 +1,20 @@
 import sys
 from os import environ
 
-import pg8000
-
 import pytest
 
+import pg8000
+
 
 @pytest.fixture(scope="class")
 def db_kwargs():
-    db_connect = {
-        'user': 'postgres',
-        'password': 'pw'
-    }
+    db_connect = {"user": "postgres", "password": "pw"}
 
     for kw, var, f in [
-                ('host', 'PGHOST', str),
-                ('password', 'PGPASSWORD', str),
-                ('port', 'PGPORT', int)
-            ]:
+        ("host", "PGHOST", str),
+        ("password", "PGPASSWORD", str),
+        ("port", "PGPORT", int),
+    ]:
         try:
             db_connect[kw] = f(environ[var])
         except KeyError:
@@ -58,4 +55,4 @@ def cursor(request, con):
 
 @pytest.fixture
 def is_java():
-    return 'java' in sys.platform.lower()
+    return "java" in sys.platform.lower()
