@@ -82,7 +82,7 @@ def test_null_roundtrip(con):
 def test_decimal_roundtrip(cursor):
     values = ("1.1", "-1.1", "10000", "20000", "-1000000000.123456789", "1.0", "12.44")
     for v in values:
-        cursor.execute("SELECT %s as f1", (decimal.Decimal(v),))
+        cursor.execute("SELECT CAST(%s AS NUMERIC)", (decimal.Decimal(v),))
         retval = cursor.fetchall()
         assert str(retval[0][0]) == v
 
@@ -130,7 +130,7 @@ def test_long_roundtrip(con):
 
 
 def test_int_execute_many_select(cursor):
-    tuple(cursor.executemany("SELECT %s", ((1,), (40000,))))
+    tuple(cursor.executemany("SELECT CAST(%s AS INTEGER)", ((1,), (40000,))))
 
 
 def test_int_execute_many_insert(cursor):
@@ -240,7 +240,7 @@ def test_timedelta_in_2_months():
 
 def test_interval_roundtrip(con):
     con.register_in_adapter(INTERVAL, pginterval_in)
-    con.register_out_adapter(PGInterval, INTERVAL, pginterval_out)
+    con.register_out_adapter(PGInterval, pginterval_out)
     v = PGInterval(microseconds=123456789, days=2, months=24)
     retval = con.run("SELECT cast(:v as interval)", v=v)
     assert retval[0][0] == v
@@ -288,11 +288,10 @@ def test_enum_custom_round_trip(con):
 
     try:
         con.run("create type lepton as enum ('1', '2', '3')")
-        lepton_oid = con.run("select oid from pg_type where typname = 'lepton'")[0][0]
-        con.register_out_adapter(Lepton, lepton_oid, lepton_out)
+        con.register_out_adapter(Lepton, lepton_out)
 
         v = Lepton("muon", "2")
-        retval = con.run("SELECT :v", v=v)
+        retval = con.run("SELECT CAST(:v AS lepton)", v=v)
         assert retval[0][0] == v.value
     finally:
         con.run("drop type lepton")
@@ -421,7 +420,7 @@ def test_timestamp_mismatch(is_java, cursor):
             # query for it, we get the same time back, like the tz was
             # dropped.
             f2 = retval[0][1]
-            assert f2 == Datetime(2001, 2, 3, 4, 5, 6, 170000)
+            assert f2 == Datetime(2001, 2, 3, 11, 5, 6, 170000)
         finally:
             cursor.execute("SET SESSION TIME ZONE DEFAULT")
 
