@@ -1,23 +1,20 @@
 import sys
 from os import environ
 
-import pg8000.native
-
 import pytest
 
+import pg8000.native
+
 
 @pytest.fixture(scope="class")
 def db_kwargs():
-    db_connect = {
-        'user': 'postgres',
-        'password': 'pw'
-    }
+    db_connect = {"user": "postgres", "password": "pw"}
 
     for kw, var, f in [
-                ('host', 'PGHOST', str),
-                ('password', 'PGPASSWORD', str),
-                ('port', 'PGPORT', int)
-            ]:
+        ("host", "PGHOST", str),
+        ("password", "PGPASSWORD", str),
+        ("port", "PGPORT", int),
+    ]:
         try:
             db_connect[kw] = f(environ[var])
         except KeyError:
@@ -49,10 +46,10 @@ def con(request, db_kwargs):
 def pg_version(con):
     retval = con.run("select current_setting('server_version')")
     version = retval[0][0]
-    idx = version.index('.')
+    idx = version.index(".")
     return int(version[:idx])
 
 
 @pytest.fixture(scope="module")
 def is_java():
-    return 'java' in sys.platform.lower()
+    return "java" in sys.platform.lower()
