@@ -1,13 +1,13 @@
 import ssl
 import sys
 
-import pg8000.native
-
 import pytest
 
+import pg8000.native
+
 
 def test_gss(db_kwargs):
-    """ This requires a line in pg_hba.conf that requires gss for the database
+    """This requires a line in pg_hba.conf that requires gss for the database
     pg8000_gss
     """
 
@@ -15,20 +15,21 @@ def test_gss(db_kwargs):
 
     # Should raise an exception saying gss isn't supported
     with pytest.raises(
-            pg8000.native.InterfaceError,
-            match="Authentication method 7 not supported by pg8000."):
+        pg8000.native.InterfaceError,
+        match="Authentication method 7 not supported by pg8000.",
+    ):
         pg8000.native.Connection(**db_kwargs)
 
 
 # Check if running in Jython
-if 'java' in sys.platform:
+if "java" in sys.platform:
     from javax.net.ssl import TrustManager, X509TrustManager
     from jarray import array
     from javax.net.ssl import SSLContext
 
     class TrustAllX509TrustManager(X509TrustManager):
-        '''Define a custom TrustManager which will blindly accept all
-        certificates'''
+        """Define a custom TrustManager which will blindly accept all
+        certificates"""
 
         def checkClientTrusted(self, chain, auth):
             pass
@@ -38,6 +39,7 @@ if 'java' in sys.platform:
 
         def getAcceptedIssuers(self):
             return None
+
     # Create a static reference to an SSLContext which will use
     # our custom TrustManager
     trust_managers = array([TrustAllX509TrustManager()], TrustManager)
@@ -50,13 +52,14 @@ if 'java' in sys.platform:
 
 @pytest.fixture
 def trust_all_certificates(request):
-    '''Decorator function that will make it so the context of the decorated
-    method will run with our TrustManager that accepts all certificates'''
+    """Decorator function that will make it so the context of the decorated
+    method will run with our TrustManager that accepts all certificates"""
     # Only do this if running under Jython
-    is_java = 'java' in sys.platform
+    is_java = "java" in sys.platform
 
     if is_java:
         from javax.net.ssl import SSLContext
+
         SSLContext.setDefault(TRUST_ALL_CONTEXT)
 
     def fin():
@@ -78,17 +81,19 @@ def test_ssl(db_kwargs):
 # This requires a line in pg_hba.conf that requires scram-sha-256 for the
 # database scram_sha_256
 
+
 def test_scram_sha_256(db_kwargs):
     db_kwargs["database"] = "pg8000_scram_sha_256"
 
     # Should only raise an exception saying db doesn't exist
-    with pytest.raises(pg8000.native.DatabaseError, match='3D000'):
+    with pytest.raises(pg8000.native.DatabaseError, match="3D000"):
         pg8000.native.Connection(**db_kwargs)
 
 
 # This requires a line in pg_hba.conf that requires scram-sha-256 for the
 # database scram_sha_256
 
+
 def test_scram_sha_256_plus(db_kwargs):
     context = ssl.SSLContext()
     context.check_hostname = False
@@ -97,5 +102,5 @@ def test_scram_sha_256_plus(db_kwargs):
 
     print(db_kwargs)
     # Should only raise an exception saying db doesn't exist
-    with pytest.raises(pg8000.native.DatabaseError, match='3D000'):
+    with pytest.raises(pg8000.native.DatabaseError, match="3D000"):
         pg8000.native.Connection(**db_kwargs)
